==> kolibri-0.14.7.tar.gz: kolibri-0.14.7/README.md <==

# Kolibri

[![Test status](https://img.shields.io/travis/learningequality/kolibri/develop.svg?label=tests)](https://travis-ci.org/learningequality/kolibri)
[![Build status](https://img.shields.io/buildkite/d84228011571e7dddb0a560f0358979c8a385173b4f58a11f8/develop.svg)](https://buildkite.com/learningequality/kolibri)
[![Developer docs](https://img.shields.io/badge/docs-dev-blue.svg)](http://kolibri-dev.readthedocs.org/en/develop/)
[![Developer chat](https://img.shields.io/badge/chat-dev-blue.svg)](http://webchat.freenode.net?channels=%23kolibri)
[![PyPI](https://img.shields.io/pypi/v/kolibri.svg?color=blue)](https://pypi.org/project/kolibri/)
[![Demo](https://img.shields.io/badge/demo-online-blue.svg)](http://kolibridemo.learningequality.org/)
[![User docs](https://img.shields.io/badge/docs-user-blue.svg)](http://kolibri.readthedocs.org/en/latest/)
[![Discourse topics](https://img.shields.io/discourse/https/community.learningequality.org/topics.svg?color=blue)](https://community.learningequality.org/)

This repository is for software developers wishing to contribute to Kolibri. If you are looking for help installing, configuring and using Kolibri, please refer to the [User Guide](https://kolibri.readthedocs.io/).


## What is Kolibri?

[Kolibri](https://learningequality.org/kolibri/) is the offline learning platform
from [Learning Equality](https://learningequality.org/).


## How can I use it?

Kolibri is [available for download](https://learningequality.org/download/) from our website.


## How do I get help or give feedback?

You can ask questions, make suggestions, and report issues in the [community forums](https://community.learningequality.org/).

If you have found a bug and are comfortable using Github and Markdown, you can create a [Github issue](https://github.com/learningequality/kolibri/issues) following the instructions in the issue template.


## How can I contribute?

Please see the 'contributing' section of our [developer documentation](http://kolibri-dev.readthedocs.io/).

==> kolibri-0.15.8.tar.gz: kolibri-0.15.8/README.md <==

# Kolibri

[![Python test status](https://github.com/learningequality/kolibri/actions/workflows/tox.yml/badge.svg?branch=develop)](https://github.com/learningequality/kolibri/actions/workflows/tox.yml)
[![JS test status](https://github.com/learningequality/kolibri/actions/workflows/yarn.yml/badge.svg?branch=develop)](https://github.com/learningequality/kolibri/actions/workflows/yarn.yml)
[![Build status](https://img.shields.io/buildkite/d84228011571e7dddb0a560f0358979c8a385173b4f58a11f8/develop.svg)](https://buildkite.com/learningequality/kolibri)
[![Developer docs](https://img.shields.io/badge/docs-dev-blue.svg)](http://kolibri-dev.readthedocs.org/en/develop/)
[![Developer chat](https://img.shields.io/badge/chat-dev-blue.svg)](http://webchat.freenode.net?channels=%23kolibri)
[![PyPI](https://img.shields.io/pypi/v/kolibri.svg?color=blue)](https://pypi.org/project/kolibri/)
[![Demo](https://img.shields.io/badge/demo-online-blue.svg)](http://kolibridemo.learningequality.org/)
[![User docs](https://img.shields.io/badge/docs-user-blue.svg)](http://kolibri.readthedocs.org/en/latest/)
[![Discourse topics](https://img.shields.io/discourse/https/community.learningequality.org/topics.svg?color=blue)](https://community.learningequality.org/)

This repository is for software developers wishing to contribute to Kolibri. If you are looking for help installing, configuring and using Kolibri, please refer to the [User Guide](https://kolibri.readthedocs.io/).


## What is Kolibri?

[Kolibri Learning Platform](https://learningequality.org/kolibri/): the offline-first platform for teaching and learning with technology without requiring the Internet.

Developed with and for the community by [Learning Equality](https://learningequality.org/).


## How can I use it?

Kolibri is [available for download](https://learningequality.org/download/) from our website.


## How do I get help or give feedback?

You can ask questions, make suggestions, and report issues in the [community forums](https://community.learningequality.org/).

If you have found a bug and are comfortable using Github and Markdown, you can create a [Github issue](https://github.com/learningequality/kolibri/issues) following the instructions in the issue template.


## How can I contribute?

Please see the 'contributing' section of our [developer documentation](http://kolibri-dev.readthedocs.io/).
